---
title: Database Documentation

search: true
---

# Tables

## cars

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid | uuid_generate_v4() | NOT NULL | 
make |  | text |  | NOT NULL | 
model |  | text |  | NOT NULL | 

## charger_events

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid | uuid_generate_v4() | NOT NULL | 
station_id |  | uuid |  | [station_id](#stations) | 
oem |  | user-defined |  | NOT NULL | ekm, emw
oem_id |  | character varying |  | NOT NULL | 
type |  | user-defined |  | NOT NULL | charging, bad data, old data, no data, idle
time_start |  | timestamp with time zone |  |  | 
time_stop |  | timestamp with time zone |  |  | 
kwh |  | numeric |  |  | 
readings |  | json |  |  | 
lin |  | character varying |  |  | 

### Triggers

name | timing | orientation | manipulation | statement
--- | --- | --- | --- | ---
associate_charger_event_with_station | BEFORE | ROW | INSERT | EXECUTE PROCEDURE <a href="#associate_charger_event_with_station">associate_charger_event_with_station</a>()

## knex_migrations

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | integer | nextval('knex_migrations_id_seq'::regclass) | NOT NULL | 
name |  | character varying |  |  | 
batch |  | integer |  |  | 
migration_time |  | timestamp with time zone |  |  | 

## knex_migrations_lock

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
is_locked |  | integer |  |  | 

## media_players

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
mac_address_1 |  | macaddr |  | NOT NULL | 
position |  | user-defined |  | NOT NULL | front, back
mac_address_2 |  | macaddr |  |  | 
ip_address |  | inet |  |  | 
last_checkin |  | timestamp with time zone |  |  | 
station_id |  | uuid |  | [station_id](#stations) | 
image_version |  | character varying |  |  | 

## meters

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | character varying |  | NOT NULL | 
oem |  | user-defined |  | NOT NULL | ekm, emw
position |  | user-defined |  | NOT NULL | left, right
station_id |  | uuid |  | [station_id](#stations) | 
state |  | user-defined | 'idle' |  | charging, bad data, old data, no data, idle
level |  | user-defined | 'L2' |  | L2, L3

## ocpp_messages

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid | uuid_generate_v4() | NOT NULL | 
created_at |  | timestamp with time zone | now() | NOT NULL | 
action |  | text |  | NOT NULL | 
charge_box_identity |  | text |  | NOT NULL | 
address |  | text |  | NOT NULL | 
request |  | json | '{}' | NOT NULL | 
response |  | json | '{}' | NOT NULL | 
server_initiated |  | boolean |  | NOT NULL | 

## sites

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid | uuid_generate_v4() | NOT NULL | 
salesforce_id |  | character |  |  | 
name |  | text |  |  | 
industry |  | text |  |  | 
image_url |  | text |  |  | 
street_address |  | text |  |  | 
city |  | text |  |  | 
state |  | character |  |  | 
zip_code |  | integer |  |  | 
pay_to_park |  | boolean | false | NOT NULL | 
tips |  | text |  |  | 
charging_hours_start |  | time with time zone |  |  | 
charging_hours_stop |  | time with time zone |  |  | 

## spatial_ref_sys

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
srid |  | integer |  | NOT NULL | 
auth_name |  | character varying |  |  | 
auth_srid |  | integer |  |  | 
srtext |  | character varying |  |  | 
proj4text |  | character varying |  |  | 

## stations

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid | uuid_generate_v4() | NOT NULL | 
salesforce_id |  | character |  |  | 
lin |  | character varying |  |  | 
name |  | text |  | NOT NULL | 
status |  | user-defined |  | NOT NULL | under construction, active, needs service
geolocation |  | user-defined |  | NOT NULL | 
completion_date |  | date |  |  | 
site_id |  | uuid |  | [site_id](#sites) | 
public |  | boolean | true | NOT NULL | 

## telemetry

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | integer | nextval('telemetry_id_seq'::regclass) | NOT NULL | 
station_id |  | uuid |  | [station_id](#stations) | 
mac_address |  | macaddr |  |  | 
ambient_temp |  | real |  |  | 
created_at |  | timestamp with time zone |  |  | 
display_1_status |  | user-defined |  |  | connected, disconnected
display_2_status |  | user-defined |  |  | connected, disconnected
image_version |  | character varying |  |  | 
local_ip_address |  | inet |  |  | 

### Triggers

name | timing | orientation | manipulation | statement
--- | --- | --- | --- | ---
associate_telemetry_with_station | BEFORE | ROW | INSERT | EXECUTE PROCEDURE <a href="#associate_telemetry_with_station">associate_telemetry_with_station</a>()
check_mac_address_integrity | BEFORE | ROW | INSERT | EXECUTE PROCEDURE <a href="#check_mac_address_integrity">check_mac_address_integrity</a>()

## user_cars

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
user_id |  | uuid |  |  | 
created_at |  | timestamp with time zone | CURRENT_TIMESTAMP |  | 
car_id |  | uuid |  | NOT NULL, [car_id](#cars) | 
avatar_id |  | integer |  | NOT NULL | 

## user_checkins

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid | uuid_generate_v4() | NOT NULL | 
user_id |  | uuid |  | NOT NULL | 
car_id |  | uuid |  | NOT NULL, [car_id](#cars) | 
device_id |  | character varying |  | NOT NULL | 
meter_id |  | character varying |  | NOT NULL | 
station_id |  | uuid |  | NOT NULL, [station_id](#stations) | 
created_at |  | timestamp with time zone | CURRENT_TIMESTAMP |  | 

## user_stations

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
user_id |  | uuid |  | NOT NULL | 
station_id |  | uuid |  | NOT NULL | 
created_at |  | timestamp with time zone | CURRENT_TIMESTAMP |  | 

# Views

## geography_columns

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
f_table_catalog |  | name |  |  | 
f_table_schema |  | name |  |  | 
f_table_name |  | name |  |  | 
f_geography_column |  | name |  |  | 
coord_dimension |  | integer |  |  | 
srid |  | integer |  |  | 
type |  | text |  |  | 

## geometry_columns

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
f_table_catalog |  | character varying |  |  | 
f_table_schema |  | name |  |  | 
f_table_name |  | name |  |  | 
f_geometry_column |  | name |  |  | 
coord_dimension |  | integer |  |  | 
srid |  | integer |  |  | 
type |  | character varying |  |  | 

## public_sites_api_view

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid |  |  | 
name |  | text |  |  | 
industry |  | text |  |  | 
image_url |  | text |  |  | 
tips |  | text |  |  | 
pay_to_park |  | boolean |  |  | 
street_address |  | text |  |  | 
city |  | text |  |  | 
state |  | character |  |  | 
zip_code |  | integer |  |  | 
chargers |  | json |  |  | 
stations |  | json |  |  | 
location |  | json |  |  | 
geolocation |  | user-defined |  |  | 

## raster_columns

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
r_table_catalog |  | name |  |  | 
r_table_schema |  | name |  |  | 
r_table_name |  | name |  |  | 
r_raster_column |  | name |  |  | 
srid |  | integer |  |  | 
scale_x |  | double precision |  |  | 
scale_y |  | double precision |  |  | 
blocksize_x |  | integer |  |  | 
blocksize_y |  | integer |  |  | 
same_alignment |  | boolean |  |  | 
regular_blocking |  | boolean |  |  | 
num_bands |  | integer |  |  | 
pixel_types |  | array |  |  | 
nodata_values |  | array |  |  | 
out_db |  | array |  |  | 
extent |  | user-defined |  |  | 
spatial_index |  | boolean |  |  | 

## raster_overviews

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
o_table_catalog |  | name |  |  | 
o_table_schema |  | name |  |  | 
o_table_name |  | name |  |  | 
o_raster_column |  | name |  |  | 
r_table_catalog |  | name |  |  | 
r_table_schema |  | name |  |  | 
r_table_name |  | name |  |  | 
r_raster_column |  | name |  |  | 
overview_factor |  | integer |  |  | 

## sites_api_view

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid |  |  | 
name |  | text |  |  | 
industry |  | text |  |  | 
image_url |  | text |  |  | 
tips |  | text |  |  | 
pay_to_park |  | boolean |  |  | 
street_address |  | text |  |  | 
city |  | text |  |  | 
state |  | character |  |  | 
zip_code |  | integer |  |  | 
chargers |  | json |  |  | 
stations |  | json |  |  | 
location |  | json |  |  | 
geolocation |  | user-defined |  |  | 

## sites_metrics_api_view

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid |  |  | 
name |  | text |  |  | 
location |  | text |  |  | 
station_status |  | json |  |  | 
charger_status |  | json |  |  | 
station_count |  | bigint |  |  | 

## stations_api_view

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid |  |  | 
lin |  | character varying |  |  | 
name |  | text |  |  | 
status |  | user-defined |  |  | under construction, active, needs service
site_id |  | uuid |  |  | 
location |  | json |  |  | 
completion_date |  | date |  |  | 
meters |  | json |  |  | 
street_address |  | text |  |  | 
city |  | text |  |  | 
state |  | character |  |  | 
zip_code |  | integer |  |  | 
public |  | boolean |  |  | 

## stations_detail_api_view

column | comment | type | default | constraints | values
--- | --- | --- | --- | --- | ---
id |  | uuid |  |  | 
lin |  | character varying |  |  | 
name |  | text |  |  | 
status |  | user-defined |  |  | under construction, active, needs service
site_id |  | uuid |  |  | 
location |  | json |  |  | 
completion_date |  | date |  |  | 
meters |  | json |  |  | 
street_address |  | text |  |  | 
city |  | text |  |  | 
state |  | character |  |  | 
zip_code |  | integer |  |  | 
public |  | boolean |  |  | 

# Functions

## associate_telemetry_with_station




    BEGIN

        NEW.station_id := (

          SELECT station_id

          FROM media_players

          WHERE media_players.mac_address_1 = NEW.mac_address

          OR media_players.mac_address_2 = NEW.mac_address

        );

        RETURN NEW;

    END;

    

## check_mac_address_integrity




    BEGIN

        IF NOT EXISTS (

            SELECT count(*) FROM media_players 

            WHERE media_players.mac_address_1 = NEW.mac_address 

            OR media_players.mac_address_2 = NEW.mac_address

          ) 

        THEN 

          RAISE EXCEPTION 'mac_address integrity error: %', NEW.mac_address;

        END IF;

        

        RETURN NEW;

    END;

    

## associate_charger_event_with_station




BEGIN

    IF NEW.station_id IS NULL THEN

        NEW.station_id := (

          SELECT station_id

          FROM meters

          WHERE meters.id = NEW.oem_id

          AND meters.oem = NEW.oem

        );

    END IF;

    RETURN NEW;

END;



# Extensions

name | version | description
--- | --- | ---
plpgsql | 1.0 | PL/pgSQL procedural language
postgis | 2.4.3 | PostGIS geometry, geography, and raster spatial types and functions
postgis_topology | 2.4.3 | PostGIS topology spatial types and functions
fuzzystrmatch | 1.1 | determine similarities and distance between strings
postgis_tiger_geocoder | 2.4.3 | PostGIS tiger geocoder and reverse geocoder
uuid-ossp | 1.1 | generate universally unique identifiers (UUIDs)

  